<?php # $Id:$
# Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
# All rights reserved.  See LICENSE file for licensing details
# Translation for european portuguese (c) by J P Matos <jmatos@math.ist.utl.pt>
# based on work (c) by Ranulfo Netto <rcnetto@yahoo.com>
# and compairison with the work (c) by Agner Olson <agner@agner.net>
# and even more work from Angel pticore@users.sourceforge.net
/* vim: set sts=4 ts=4 expandtab : */

@define('LANG_CHARSET', 'ISO-8859-1');
@define('SQL_CHARSET', 'latin1');
@define('DATE_LOCALES', 'pt_PT.ISO-8859-1, pt_PT.ISO8859-1, pt, pt_PT, european portuguese');
@define('DATE_FORMAT_ENTRY', '%A, %e de %B de %Y');
@define('DATE_FORMAT_SHORT', '%Y-%m-%d %H:%M');
@define('WYSIWYG_LANG', 'pt_pt');
@define('NUMBER_FORMAT_DECIMALS', '2');
@define('NUMBER_FORMAT_DECPOINT', ',');
@define('NUMBER_FORMAT_THOUSANDS', '.');
@define('LANG_DIRECTION', 'ltr');

@define('SERENDIPITY_ADMIN_SUITE', 'Painel de Administrao do Serendipity');
@define('HAVE_TO_BE_LOGGED_ON', 'Tem que efectuar login no sistema para visualizar esta pgina');
@define('WRONG_USERNAME_OR_PASSWORD', 'Deve ter fornecido um nome de utilizador, senha ou dados invlidos');
@define('APPEARANCE', 'Aparncia');
@define('MANAGE_STYLES', 'Gerir estilos');
@define('CONFIGURE_PLUGINS', 'Configurar Plugins');
@define('CONFIGURATION', 'Configurao');
@define('BACK_TO_BLOG', 'Regressar ao Weblog');
@define('LOGIN', 'Login'); //
@define('LOGOUT', 'Sair'); // Verify
@define('LOGGEDOUT', 'Sada completada.'); // Verify
@define('CREATE', 'Criar');
@define('SAVE', 'Guardar');
@define('NAME', 'Nome');
@define('CREATE_NEW_CAT', 'Criar uma nova categoria');
@define('I_WANT_THUMB', 'Quero usar miniaturas no meu artigo.');
@define('I_WANT_BIG_IMAGE', 'Quero usar a maior imagem no meu artigo.');
@define('I_WANT_NO_LINK', ' Quero mostr-la como imagem');
@define('I_WANT_IT_TO_LINK', 'Quero mostr-la como uma ligao para este URL:');
@define('BACK', 'Volta');
@define('FORWARD', 'Encaminhar');
@define('ANONYMOUS', 'Annimo');
@define('NEW_TRACKBACK_TO', 'Novo trackback feito para');
@define('NEW_COMMENT_TO', 'Novo comentrio enviado para');
@define('RECENT', 'Recentes...');
@define('OLDER', 'Mais antigos...');
@define('DONE', 'Pronto');
@define('WELCOME_BACK', 'Bem vindo de volta,');
@define('TITLE', 'Ttulo');
@define('DESCRIPTION', 'Descrio');
@define('PLACEMENT', 'Localizao');
@define('DELETE', 'Apagar');
@define('SAVE', 'Guardar');
@define('UP', 'Para cima');
@define('DOWN', 'Para baixo');
@define('ENTRIES', 'Artigos:');
@define('NEW_ENTRY', 'Novo artigo');
@define('EDIT_ENTRIES', 'Editar artigos');
@define('CATEGORIES', 'Categorias');
@define('WARNING_THIS_BLAHBLAH', "ATENO:\\nIsso pode demorar muito tempo se existirem muitas imagens sem miniaturas.");
@define('CREATE_THUMBS', 'Reconstruir miniaturas');
@define('MANAGE_IMAGES', 'Gerir imagens');
@define('NAME', 'Nome');
@define('EMAIL', 'E-mail');
@define('HOMEPAGE', 'Pgina pessoal');
@define('COMMENT', 'Comentrio');
@define('REMEMBER_INFO', 'Relembrar Informaes? ');
@define('SUBMIT_COMMENT', 'Enviar Comentrio');
@define('NO_ENTRIES_TO_PRINT', 'Nenhum artigo para imprimir');
@define('COMMENTS', 'Comentrios');
@define('ADD_COMMENT', 'Adicionar Comentrios');
@define('NO_COMMENTS', 'Nenhum comentrio');
@define('POSTED_BY', 'Publicado por');
@define('ON', 'em');
@define('A_NEW_COMMENT_BLAHBLAH', 'Um novo comentrio foi enviado para o seu Blog "%s", no artigo entitulado "%s".');
@define('A_NEW_TRACKBACK_BLAHBLAH', 'Um novo trackback foi feito para o seu Blog "%s", no artigo entitulado "%s".');
@define('NO_CATEGORY', 'Sem categoria');
@define('ENTRY_BODY', 'Corpo do artigo');
@define('EXTENDED_BODY', 'Extenso do corpo do artigo');
@define('CATEGORY', 'Categoria:');
@define('EDIT', 'Editar');
@define('NO_ENTRIES_BLAHBLAH', 'Nenhum artigo encontrado para a consulta %s' . "\n");
@define('YOUR_SEARCH_RETURNED_BLAHBLAH', 'A sua busca de %s obteve %s resultados:');
@define('IMAGE', 'Imagem');
@define('ERROR_FILE_NOT_EXISTS', 'Erro: O nome de ficheiro antigo no existe!');
@define('ERROR_FILE_EXISTS', 'Erro: O novo nome de ficheiro j existe, escolha outro!');
@define('ERROR_SOMETHING', 'Erro: Problema desconhecido.');
@define('ADDING_IMAGE', 'Adicionando imagem...');
@define('THUMB_CREATED_DONE', 'Miniatura criada.<br/>Pronto.');
@define('ERROR_FILE_EXISTS_ALREADY', 'Erro: O ficheiro j existe no seu servidor!');
@define('GO', 'Vamos!');
@define('NEWSIZE', 'Novo tamanho: ');
@define('RESIZE_BLAHBLAH', '<b>Redimensionar %s</b><p>');
@define('ORIGINAL_SIZE', 'Tamanho original: <i>%sx%s</i> pixis');
@define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>Aqui pode ajustar o novo tamanho das suas imagens. Se pretender manter as propores, preencha apenas um valor e pressione a tecla TAB de maneira a ser automaticamente calculado o novo tamanho de modo s propores no ficarem erradas:');
@define('QUICKJUMP_CALENDAR', 'Calendrio de acesso rpido');
@define('QUICKSEARCH', 'Pesquisa rpida');
@define('SEARCH_FOR_ENTRY', 'Procure um artigo');
@define('ARCHIVES', 'Arquivos');
@define('BROWSE_ARCHIVES', 'Navegar nos arquivos por ms');
@define('TOP_REFERRER', 'Referenciadores mais importantes');
@define('SHOWS_TOP_SITES', 'Exibe os links de entrada mais utilizados para aceder no seu blogue');
@define('TOP_EXITS', 'Sadas Maiores');
@define('SHOWS_TOP_EXIT', 'Exibe os links de sada mais requisitados de seu blogue');
@define('SYNDICATION', 'Sindicalizao');
@define('SHOWS_RSS_BLAHBLAH', 'Mostrar ligaes de sindicalizao RSS');
@define('ADVERTISES_BLAHBLAH', 'Publicita a origem do seu blogue');
@define('HTML_NUGGET', 'Fragmento de HTML');
@define('HOLDS_A_BLAHBLAH', 'Apresenta um fragmento de HTML na sua barra lateral');
@define('TITLE_FOR_NUGGET', 'Ttulo para o fragmento de HTML');
@define('THE_NUGGET', 'Fragmento de HTML!');
@define('SYNDICATE_THIS_BLOG', 'Sindicalizar este Blogue');
@define('YOU_CHOSE', 'Escolheu %s');
@define('IMAGE_SIZE', 'Tamanho da imagem');
@define('IMAGE_AS_A_LINK', 'Insero de imagem');
@define('POWERED_BY', 'Equipado com');
@define('TRACKBACKS', 'Trackbacks');
@define('TRACKBACK', 'Trackback');
@define('NO_TRACKBACKS', 'Nenhuns Trackbacks');
@define('TOPICS_OF', 'Tpicos de');
@define('VIEW_FULL', 'ver tudo');
@define('VIEW_TOPICS', 'ver tpicos');
@define('AT', 's');
@define('SET_AS_TEMPLATE', 'Definir como modelo');
@define('IN', 'em');
@define('EXCERPT', 'Excerto');
@define('TRACKED', 'Tracked'); // Translate?
@define('LINK_TO_ENTRY', 'Ligao para o artigo');
@define('LINK_TO_REMOTE_ENTRY', 'Ligao para artigo remoto');
@define('IP_ADDRESS', 'Endereo IP');
@define('USER', 'Utilizador');
@define('THUMBNAIL_USING_OWN', 'Usando %s como a sua prpria miniatura devido ao seu pequeno tamanho.');
@define('THUMBNAIL_FAILED_COPY', 'A tentativa de usar %s como a sua prpria miniatura falhou devido a um erro na cpia!');
@define('AUTHOR', 'Autor');
@define('LAST_UPDATED', 'ltima actualizao');
@define('TRACKBACK_SPECIFIC', 'URI especfica do trackback para este artigo');
@define('DIRECT_LINK', 'Ligao directa para este artigo');
@define('COMMENT_ADDED', 'O seu comentrio foi adicionado correctamente.');
@define('COMMENT_ADDED_CLICK', 'Clique %saqui para retornar%s aos comentrios, ou %saqui para fechar%s esta janela.');
@define('COMMENT_NOT_ADDED_CLICK', 'Clique %saqui para retornar%s aos comentrios, ou %saqui para fechar%s esta janela.');
@define('COMMENTS_DISABLE', 'No so permitidos comentrios neste artigo');
@define('COMMENTS_ENABLE', 'So permitidos comentrios neste artigo');
@define('COMMENTS_CLOSED', 'O autor no autorizou comentrios deste artigo');
@define('EMPTY_COMMENT', 'O seu comentrio est vazio, por favor, %svolte%s e tente novamente');
@define('ENTRIES_FOR', 'Artigos para %s');
@define('DOCUMENT_NOT_FOUND', 'O documento %s no foi encontrado.');
@define('USERNAME', 'Utilizador');
@define('PASSWORD', 'Senha');
@define('AUTOMATIC_LOGIN', 'Guardar informaes');
@define('SERENDIPITY_INSTALLATION', 'Instalao do Serendipity');
@define('LEFT', 'esquerda');
@define('RIGHT', 'direita');
@define('HIDDEN', 'oculto');
@define('REMOVE_TICKED_PLUGINS', 'Remover plugins marcados');
@define('SAVE_CHANGES_TO_LAYOUT', 'Guardar modificaes ao layout');
@define('COMMENTS_FROM', 'Comentrios de');
@define('ERROR', 'Erro');
@define('ENTRY_SAVED', 'Artigo guardado');
@define('DELETE_SURE', 'Tem a certeza que deseja excluir #%s definitivamente?');
@define('NOT_REALLY', 'No mesmo...');
@define('DUMP_IT', 'Elimin-lo!');
@define('RIP_ENTRY', 'Destruir artigo #%s');
@define('CATEGORY_DELETED', 'Categoria #%s apagada. Os artigos antigos foram movidos para a categoria #%s');
@define('INVALID_CATEGORY', 'Nenhuma categoria fornecida para excluso');
@define('CATEGORY_SAVED', 'Categoria guardada');
@define('SELECT_TEMPLATE', 'Selecione o modelo pretendido para o seu Blogue');
@define('ENTRIES_NOT_SUCCESSFULLY_INSERTED', 'Artigos no adicionados!');
@define('YES', 'Sim');
@define('NO', 'No');
@define('USE_DEFAULT', 'Por omisso');
@define('CHECK_N_SAVE', 'Verificar &amp; guardar');
@define('DIRECTORY_WRITE_ERROR', 'No foi possvel escrever na directoria %s. Verifique as permisses.');
@define('DIRECTORY_CREATE_ERROR', 'A directoria %s no existe e no pode ser criada. Tente cri-la manualmente');
@define('DIRECTORY_RUN_CMD', '&nbsp;-&gt; execute <i>%s %s</i>');
@define('CANT_EXECUTE_BINARY', 'No foi possvel executar o binrio %s');
@define('FILE_WRITE_ERROR', 'No foi possvel editar o ficheiro %s.');
@define('FILE_CREATE_YOURSELF', 'Por favor, crie voc mesmo o ficheiro ou verifique as suas permisses');
@define('COPY_CODE_BELOW', '<br />* Copie o cdigo abaixo e o coloque em %s na sua %s directoria:<b><pre>%s</pre></b>' . "\n");
@define('WWW_USER', 'Altere www para o utilizador com o qual o apache  executado (ex.: ningum).');
@define('BROWSER_RELOAD', 'Uma vez feito isso, pressione o boto "actualizar" ("reload") do seu navegador.');
@define('DIAGNOSTIC_ERROR', 'Detectmos alguns erros quando verificmos as informaes que forneceu:');
@define('SERENDIPITY_NOT_INSTALLED', 'Serendipity no se encontra instalado. Por favor <a href="%s">instale-o</a> agora.');
@define('INCLUDE_ERROR', 'Erro do Serendipity: no foi possvel incluir %s - abortando.');
@define('DATABASE_ERROR', 'Erro do Serendipity: no foi possvel conectar-se  base de dados - abortando.');
@define('CREATE_DATABASE', 'Criando a instalao padro da base de dados...');
@define('ATTEMPT_WRITE_FILE', 'Tentando editar o ficheiro %s...');
@define('WRITTEN_N_SAVED', 'Configurao escrita &amp; guardada');
@define('IMAGE_ALIGNMENT', 'Alinhamento de imagem');
@define('ENTER_NEW_NAME', 'Indique um nome novo: ');
@define('RESIZING', 'Redimensionando');
@define('RESIZE_DONE', 'Pronto (%s imagens redimensionadas).');
@define('SYNCING', 'Sincronizando a base de dados com a directoria de imagens');
@define('SYNC_DONE', 'Pronto (%s imagens sincronizadas).');
@define('DELETE_IMAGE_FAIL' , 'No foi possvel excluir a imagem <b>%s</b>');
@define('DELETE_THUMBNAIL', 'Excluir a miniatura da imagem entitulada <b>%s</b>');
@define('FILE_NOT_FOUND', 'No foi possvel localizar o ficheiro entitulado <b>%s</b>, ser que foi apagado?');
@define('ABORT_NOW', 'Cancelar agora');
@define('REMOTE_FILE_NOT_FOUND', 'O arquivo no foi localizado no servidor, tem a certeza que a URL: <b>%s</b> est correcta?');
@define('FILE_FETCHED', '%s obtido como %s');
@define('FILE_UPLOADED', 'O arquivo %s foi transferido correctamente: %s');
@define('WORD_OR', 'Ou');
@define('SCALING_IMAGE', 'Redimensionando %s para %s x %s px');
@define('KEEP_PROPORTIONS', 'Manter propores');
@define('REALLY_SCALE_IMAGE', 'Quer mesmo redimensionar a imagem? No  possvel desfazer!!');
@define('TOGGLE_ALL', 'Alternar para expandir tudo');
@define('TOGGLE_OPTION', 'Opo para alternar');
@define('SUBSCRIBE_TO_THIS_ENTRY', 'Subscrever a este artigo');
@define('UNSUBSCRIBE_OK', "%s teve a subscrio deste artigo cancelada");
@define('NEW_COMMENT_TO_SUBSCRIBED_ENTRY', 'Novo comentrio no artigo subscrito "%s"');
@define('SUBSCRIPTION_MAIL', "Ol %s,\n\nUm novo comentrio foi acrescentado a um artigo que voc est seguindo em \"%s\", intitulado \"%s\"\nO comentrio foi enviado por: %s\n\nO artigo a que nos referimos pode ser encontrado em: %s\n\nPode cancelar sua subscrio clicando esta ligao: %s\n");
@define('SUBSCRIPTION_TRACKBACK_MAIL', "Ol %s,\n\nUm novo trackback foi adicionado num artigo que voc est seguindo em \"%s\", intitulado \"%s\"\nO comentrio foi enviado por: %s\n\nO artigo a que nos referimos pode ser encontrada em: %s\n\nPode cancelar a sua subscrio clicando nesta ligao: %s\n");
@define('SIGNATURE', "\n-- \n%s faz uso do Serendipity.\nO melhor Blogue que existe, e voc tambm pode us-lo.\nConsulte <http://s9y.org> para descobrir como.");
@define('SYNDICATION_PLUGIN_091', 'RSS 0.91 feed');
@define('SYNDICATION_PLUGIN_10', 'RSS 1.0 feed');
@define('SYNDICATION_PLUGIN_20', 'RSS 2.0 feed');
@define('SYNDICATION_PLUGIN_20c', 'RSS 2.0 comentrios');
@define('SYNDICATION_PLUGIN_ATOM03', 'ATOM 0.3 feed');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR', 'Campo "managingEditor"');
@define('SYNDICATION_PLUGIN_WEBMASTER',  'Campo "webMaster"');
@define('SYNDICATION_PLUGIN_BANNERURL', 'Imagem para o RSS feed');
@define('SYNDICATION_PLUGIN_BANNERWIDTH', 'Largura da imagem');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT', 'Altura da imagem');
@define('SYNDICATION_PLUGIN_WEBMASTER_DESC',  'E-mail do webmaster, se disponvel. (vazio: oculto) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR_DESC', 'E-mail do editor, se disponvel. (vazio: oculto) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_BANNERURL_DESC', 'URL de uma imagem no formato GIF/JPEG/PNG, se disponvel. (vazio: logotipo do serendipity)');
@define('SYNDICATION_PLUGIN_BANNERWIDTH_DESC', 'em pixis, max. 144');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT_DESC', 'em pixis, max. 400');
@define('SYNDICATION_PLUGIN_TTL', 'Campo "ttl" (tempo de vida)');
@define('SYNDICATION_PLUGIN_TTL_DESC', 'Quantidade de minutos depois do qual o seu blogue no dever ser mais "cacheado" por stios ou aplicaes (vazio: oculto) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_PUBDATE', 'Campo "pubDate"');
@define('SYNDICATION_PLUGIN_PUBDATE_DESC', 'O campo "pubDate" deve ser empacotado para o canal RSS, para mostrar a data do ltimo artigo?');
@define('CONTENT', 'Contedo');
@define('TYPE', 'Tipo');
@define('DRAFT', 'Rascunho');
@define('PUBLISH', 'Publicar');
@define('PREVIEW', 'Pr-visualizao');
@define('DATE', 'Data');
@define('DATE_FORMAT_2', 'Y-m-d H:i'); // Needs to be ISO 8601 compliant for date conversion!
@define('DATE_INVALID', 'ATENO: A data que voc especificou  invlida. Deve ser fornecida no formato DD/MM/AAAA HH:MM.');
@define('CATEGORY_PLUGIN_DESC', 'Mostra a listagem de categorias.');
@define('ALL_AUTHORS', 'Todos os Autores');
@define('CATEGORIES_TO_FETCH', 'Categorias para trazer');
@define('CATEGORIES_TO_FETCH_DESC', 'Trazer categorias de que Autor?');
@define('PAGE_BROWSE_ENTRIES', 'Pgina %s de %s, totalizando %s artigos');
@define('PREVIOUS_PAGE', 'pgina anterior');
@define('NEXT_PAGE', 'pgina seguinte');
@define('ALL_CATEGORIES', 'Todas as categorias');
@define('DO_MARKUP', 'Executar transformaes de marcao');
@define('GENERAL_PLUGIN_DATEFORMAT', 'Formatao de data');
@define('GENERAL_PLUGIN_DATEFORMAT_BLAHBLAH', 'Formato da data actual do artigo, usando a mesma formatao da funo strftime() do PHP. (Padro: "%s")');
@define('ERROR_TEMPLATE_FILE', 'No foi possvel abrir o ficheiro modelo, por favor actualize o Serendipity!');
@define('ADVANCED_OPTIONS', 'Opes avanadas');
@define('EDIT_ENTRY', 'Editar artigo');
@define('HTACCESS_ERROR', 'Para verificar a instalao do servidor web, Serendipity necessita ter o poder para criar o arquivo ".htaccess". Isso no foi possvel devido a erros nas permisses. Por favor, ajuste as permisses para: <br />&nbsp;&nbsp;%s<br />e recarregue esta pgina.');
@define('SIDEBAR_PLUGINS', 'Plugins da barra lateral');
@define('EVENT_PLUGINS', 'Plugins de eventos');
@define('SORT_ORDER', 'Ordenao');
@define('SORT_ORDER_NAME', 'Nome do ficheiro');
@define('SORT_ORDER_EXTENSION', 'Extenso do ficheiro');
@define('SORT_ORDER_SIZE', 'Tamanho do ficheiro');
@define('SORT_ORDER_WIDTH', 'Largura da imagem');
@define('SORT_ORDER_HEIGHT', 'Altura da imagem');
@define('SORT_ORDER_DATE', 'Data de transferncia');
@define('SORT_ORDER_ASC', 'Ascendente');
@define('SORT_ORDER_DESC', 'Descendente');
@define('THUMBNAIL_SHORT', 'Miniatura');
@define('ORIGINAL_SHORT', 'Orig.');
@define('APPLY_MARKUP_TO', 'Aplicar cdigo a %s');
@define('CALENDAR_BEGINNING_OF_WEEK', 'Comeo da semana');
@define('SERENDIPITY_NEEDS_UPGRADE', 'O Serendipity detectou que a configurao est de acordo com a verso %s, embora a verso %s de Serendipity esteja instalada. Precisa de actualizar o Serendipity! <a href="%s">Clique aqui</a>');
@define('SERENDIPITY_UPGRADER_WELCOME', 'Ol, e bem-vindo ao agente de actualizao do Serendipity.');
@define('SERENDIPITY_UPGRADER_PURPOSE', 'Estou aqui para ajud-lo a actualizar na instalao %s do seu Serendipity.');
@define('SERENDIPITY_UPGRADER_WHY', 'Voc est a ver esta mensagem porque acabou de instalar o Serendipity %s, mas ainda no actualizou a instalao da base de dados para compatibilizar com esta verso');
@define('SERENDIPITY_UPGRADER_DATABASE_UPDATES', 'Actualizao da base de dados (%s)');
@define('SERENDIPITY_UPGRADER_FOUND_SQL_FILES', 'Encontrei os seguintes arquivos .sql u]que precisam ser executados antes que voc prossiga com a utilizao normal do Serendipity');
@define('SERENDIPITY_UPGRADER_VERSION_SPECIFIC',  'Tarefas especficas da verso');
@define('SERENDIPITY_UPGRADER_NO_VERSION_SPECIFIC', 'Nenhuma tarefa especfica da verso foi encontrada');
@define('SERENDIPITY_UPGRADER_PROCEED_QUESTION', 'Quer realizar as tarefas acima?');
@define('SERENDIPITY_UPGRADER_PROCEED_ABORT', 'No, eu as executarei manualmente');
@define('SERENDIPITY_UPGRADER_PROCEED_DOIT', 'Por favor, faa isso');
@define('SERENDIPITY_UPGRADER_NO_UPGRADES', 'Parece que que voc no precisa executar nenhuma actualizao');
@define('SERENDIPITY_UPGRADER_CONSIDER_DONE', 'Considere a actualizao do Serendipity');
@define('SERENDIPITY_UPGRADER_YOU_HAVE_IGNORED', 'Voc ignorou a fase de actualizao do Serendipity, certifique-se de que a base de dados est instalada correctamente e que as funes necessrias foram executadas');
@define('SERENDIPITY_UPGRADER_NOW_UPGRADED', 'A sua instalao do Serendipity foi actualizada para a verso %s');
@define('SERENDIPITY_UPGRADER_RETURN_HERE', 'Pode retornar ao seu Blogue clicando %saqui%s');

@define('MANAGE_USERS', 'Gerir utilizadores');
@define('CREATE_NEW_USER', 'Criar novo utilizador');
@define('CREATE_NOT_AUTHORIZED', 'Voc no pode modificar utilizadores que tenham o mesmo nvel que o seu');
@define('CREATE_NOT_AUTHORIZED_USERLEVEL', 'Voc no pode criar utilizadores com um nvel maior que o seu');
@define('CREATED_USER', 'Um novo utilizador %s foi criado');
@define('MODIFIED_USER', 'As propriedades do utilizador %s foram alteradas');
@define('USER_LEVEL', 'Nvel do utilizador');
@define('DELETE_USER', 'Voc est prestes a suprimir o utilizador #%d %s. Tem a certeza disso? Isso far com que os artigos escritos por ele deixem de ser consultveis.');
@define('DELETED_USER', 'Utilizador #%d %s excludo.');
@define('LIMIT_TO_NUMBER', 'Quantos itens devem ser apresentados?');
@define('ENTRIES_PER_PAGE', 'artigos por pgina');
@define('XML_IMAGE_TO_DISPLAY', 'Boto XML');
@define('XML_IMAGE_TO_DISPLAY_DESC','Links para XML Feeds sero exibidos por esta imagem. Deixe em branco para padro, digite \'none\' para tornar inactivo.');

@define('DIRECTORIES_AVAILABLE', 'Na lista de subdirectorias disponveis, voc pode clicar em qualquer nome de subdirectoria para criar uma nova directoria dentro daquela estrutura.');
@define('ALL_DIRECTORIES', 'todas as directorias');
@define('MANAGE_DIRECTORIES', 'Gerir directorias');
@define('DIRECTORY_CREATED', 'Directoria <strong>%s</strong> foi criada.');
@define('PARENT_DIRECTORY', 'Directoria superior');
@define('CONFIRM_DELETE_DIRECTORY', 'Tem a certeza que quer apagar todo o contedo da directoria %s?');
@define('ERROR_NO_DIRECTORY', 'Erro: A Directoria %s no existe');
@define('CHECKING_DIRECTORY', 'Verificando arquivos na directoria %s');
@define('DELETING_FILE', 'Apagando ficheiro %s...');
@define('ERROR_DIRECTORY_NOT_EMPTY', 'No foi possvel remover uma directoria que no est vazia. Marque a opo "forar apagar" se tambm deseja remover os ficheiros nela contidos, e volte a dar o comando. Os ficheiros existentes so:');
@define('DIRECTORY_DELETE_FAILED', 'A remoo da directoria %s falhou. Verifique as permisses ou as mensagens acima.');
@define('DIRECTORY_DELETE_SUCCESS', 'Directoria %s removida correctamente.');
@define('SKIPPING_FILE_EXTENSION', 'Ignorando ficheiro: Falta extenso em %s.');
@define('SKIPPING_FILE_UNREADABLE', 'Ignorando ficheiro: %s ilegvel.');
@define('FOUND_FILE', 'Encontrado ficheiro novo/modificado: %s.');
@define('ALREADY_SUBCATEGORY', '%s j  uma subcategoria de %s.');
@define('PARENT_CATEGORY', 'Categoria superior');
@define('IN_REPLY_TO', 'Em resposta a');
@define('TOP_LEVEL', 'Nvel de topo');
@define('SYNDICATION_PLUGIN_GENERIC_FEED', '%s feed');
@define('PERMISSIONS', 'Permisses');
@define('SETTINGS_SAVED_AT', 'As novas preferncias foram guardadas em %s');

/* DATABASE SETTINGS */
@define('INSTALL_CAT_DB', 'Configuraes da base de dados');
@define('INSTALL_CAT_DB_DESC', 'Aqui voc pode inserir toda a informao acerca da sua base de dados. O Serendipity requer esta informao para funcionar correctamente.');
@define('INSTALL_DBTYPE', 'Tipo de base de dados');
@define('INSTALL_DBTYPE_DESC', 'Tipo de base de dados');
@define('INSTALL_DBHOST', 'Servidor de base de dados');
@define('INSTALL_DBHOST_DESC', 'Endereo/Nome do seu servidor de base de dados');
@define('INSTALL_DBUSER', 'Utilizador da base de dados');
@define('INSTALL_DBUSER_DESC', 'O nome de utilizador que liga  base de dados');
@define('INSTALL_DBPASS', 'Senha da base de dados');
@define('INSTALL_DBPASS_DESC', 'A senha correspondente ao utilizador acima');
@define('INSTALL_DBNAME', 'Nome da base de dados');
@define('INSTALL_DBNAME_DESC', 'O nome da base de dados');
@define('INSTALL_DBPREFIX', 'Prefixo para as tabelas da base de dados');
@define('INSTALL_DBPREFIX_DESC', 'Prefixo utilizado para designar as tabelas, ex.: serendipity_');

/* PATHS */
@define('INSTALL_CAT_PATHS', 'Caminhos');
@define('INSTALL_CAT_PATHS_DESC', 'Os vrios caminhos para directorias e ficheiros essenciais. No se esquea de terminar com barras no caso das directorias');
@define('INSTALL_FULLPATH', 'Caminho completo');
@define('INSTALL_FULLPATH_DESC', 'O caminho completo e absoluto para a sua instalao de Serendipity');
@define('INSTALL_UPLOADPATH', 'Caminho para o Upload');
@define('INSTALL_UPLOADPATH_DESC', 'Todos os arquivos transferidos iro parar a, relativo ao \'Caminho completo\' - geralmente \'uploads/\'');
@define('INSTALL_RELPATH', 'Caminho relativo');
@define('INSTALL_RELPATH_DESC', 'Caminho para o Serendipity no seu navegador, geralmente \'/serendipity/\'');
@define('INSTALL_RELTEMPLPATH', 'Caminho relativo do padro');
@define('INSTALL_RELTEMPLPATH_DESC', 'Caminho para a directoria onde esto os seus padres - Relativo ao \'caminho relativo\'');
@define('INSTALL_RELUPLOADPATH', 'Caminho relativo do Upload');
@define('INSTALL_RELUPLOADPATH_DESC', 'Caminho para o \'uploads\' em seu navegador - Relativo ao \'caminho relativo\'');
@define('INSTALL_URL', 'URL do blogue');
@define('INSTALL_URL_DESC', 'URL base para a instalao do Serendipity');
@define('INSTALL_INDEXFILE', 'Arquivo inicial');
@define('INSTALL_INDEXFILE_DESC', 'Nome do arquivo inicial do Serendipity');

/* Generel settings */
@define('INSTALL_CAT_SETTINGS', 'Configuraes gerais');
@define('INSTALL_CAT_SETTINGS_DESC', 'Padro de como o Serendipity se deve comportar');
@define('INSTALL_USERNAME', 'Nome de utilizador do Administrador');
@define('INSTALL_USERNAME_DESC', 'Nome de utilizador do utilizador para o login do Administrador');
@define('INSTALL_PASSWORD', 'Senha do Administrador');
@define('INSTALL_PASSWORD_DESC', 'Senha de acesso do Administrador');
@define('INSTALL_EMAIL', 'E-mail do Administrador');
@define('INSTALL_EMAIL_DESC', 'E-mail do Administrador do blogue');
@define('INSTALL_SENDMAIL', 'Enviar e-mails ao Administrador?');
@define('INSTALL_SENDMAIL_DESC', 'Voc deseja receber notificaes via e-mail quando novos comentrios forem includos nos seus artigos?');
@define('INSTALL_SUBSCRIBE', 'Permitir que os utilizadores se inscrevam nos artigos?');
@define('INSTALL_SUBSCRIBE_DESC', 'Permitir que utilizadores se inscrevam nos artigos e com isso, recebam notificaes via e-mail quando novos comentrios forem adicionados?');
@define('INSTALL_BLOGNAME', 'Nome do Blogue');
@define('INSTALL_BLOGNAME_DESC', 'Ttulo do Blogue');
@define('INSTALL_BLOGDESC', 'Descrio do Blogue');
@define('INSTALL_BLOGDESC_DESC', 'Descrio');
@define('INSTALL_LANG', 'Idioma');
@define('INSTALL_LANG_DESC', 'Seleccione o idioma para o seu blogue');

/* Appearance and options */
@define('INSTALL_CAT_DISPLAY', 'Aparncia e opes');
@define('INSTALL_CAT_DISPLAY_DESC', 'Padroniza como o Serendipity  exibido');
@define('INSTALL_WYSIWYG', 'Usar editor WYSIWYG');
@define('INSTALL_WYSIWYG_DESC', 'Voc quer usar o editor WYSIWYG? (Funciona no IE5+ e parcialmente no Mozilla 1.3+)');
@define('INSTALL_XHTML11', 'Forar compatibilidade com XHTML 1.1');
@define('INSTALL_XHTML11_DESC', 'Quer forar compatibilidade com o standard XHTML 1.1 (pode causar problemas de formatao nos navegadores de 4 gerao (4.x))');
@define('INSTALL_POPUP', 'Permitir o uso de janelas popups');
@define('INSTALL_POPUP_DESC', 'Quer que o weblog utilize janelas popups para comentrios, trackbacks, etc?');
@define('INSTALL_EMBED', 'O Serendipity est integrado?');
@define('INSTALL_EMBED_DESC', 'Se quiser arquivar o contedo do Serendipity dum website, mude para verdadeiro para descartar quaisquer cabealhos e apenas imprimir o contedo. Pode fazer uso da opo \'Arquivo inicial\' para usar uma classe mais abrangente aonde colocaria os cabealhos normais de sua pgina. Veja o ficheiro README para mais informaes!');
@define('INSTALL_BLOCKREF', 'Referncias bloqueadas');
@define('INSTALL_BLOCKREF_DESC', 'Existem servidores especiais que voc no gostaria de listar na sua lista de referncias? Separe a lista dos servidores com \';\' e note que o servidor ser bloqueado por uma busca parcial em sua string!');
@define('INSTALL_REWRITE', 'Reescrita de URL');
@define('INSTALL_REWRITE_DESC', 'Selecione as regras que voc gostaria de usar na gerao de URLs. A habilitao da reescrita de URL criar URLS bem formatadas para o seu blogue e o deixar indexvel de um melhor modo para os bots como o do Google. O servidor web precisa de ter suporte para o mod_rewrite ou para o "AllowOverride All" para a directoria do seu Serendipity. A configurao padro  auto detectada');

/* Imageconversion Settings */
@define('INSTALL_CAT_IMAGECONV', 'Configuraes da converso de imagens');
@define('INSTALL_CAT_IMAGECONV_DESC', 'Informaes gerais sobre como o Serendipity deve lidar com imagens');
@define('INSTALL_IMAGEMAGICK', 'Usar Image magick');
@define('INSTALL_IMAGEMAGICK_DESC', 'Voc tem o \'image magick\' instalado e quer utiliz-lo para redimensionar imagens?');
@define('INSTALL_IMAGEMAGICKPATH', 'Caminho para o executvel do conversor');
@define('INSTALL_IMAGEMAGICKPATH_DESC', 'Caminho completo e nome do executvel do image magick');
@define('INSTALL_THUMBSUFFIX', 'Sufixo das miniaturas');
@define('INSTALL_THUMBSUFFIX_DESC', 'As miniaturas sero nomeadas com o seguinte formato: original.[sufixo].ext');
@define('INSTALL_THUMBWIDTH', 'Dimenso das miniaturas ');
@define('INSTALL_THUMBWIDTH_DESC', 'Largura mxima esttica das miniaturas geradas automaticamente');

/* Personal details */
@define('USERCONF_CAT_PERSONAL', 'Detalhes pessoais');
@define('USERCONF_CAT_PERSONAL_DESC', 'Altere os seus detalhes pessoais');
@define('USERCONF_USERNAME', 'O seu nome de utilizador');
@define('USERCONF_USERNAME_DESC', 'O nome de utilizador que voc usa para se identificar no blogue');
@define('USERCONF_PASSWORD', 'A sua senha');
@define('USERCONF_PASSWORD_DESC', 'A senha que voc quer usar para se identificar no blogue');
@define('USERCONF_EMAIL', 'O seu endereo de e-mail');
@define('USERCONF_EMAIL_DESC', 'O seu endereo de e-mail pessoal');
@define('USERCONF_SENDCOMMENTS', 'Enviar notificao dos comentrios?');
@define('USERCONF_SENDCOMMENTS_DESC', 'Quer receber e-mails quando forem enviados comentrios  cerca dos seus artigos?');
@define('USERCONF_SENDTRACKBACKS', 'Enviar notificao de trackbacks?');
@define('USERCONF_SENDTRACKBACKS_DESC', 'Quer receber e-mails quando trackbacks forem enviados para os seus artigos?');
@define('USERCONF_ALLOWPUBLISH', 'Direitos: Publicao de artigos?');
@define('USERCONF_ALLOWPUBLISH_DESC', 'Este utilizador est autorizado a publicar artigos?');
@define('SUCCESS', 'Sucesso');
@define('POWERED_BY_SHOW_TEXT', 'Exibir "Serendipity" como texto');
@define('POWERED_BY_SHOW_TEXT_DESC', 'Exibir o "Serendipity Weblog" como texto');
@define('POWERED_BY_SHOW_IMAGE', 'Exibir "Serendipity" como um logotipo');
@define('POWERED_BY_SHOW_IMAGE_DESC', 'Exibe o logotipo do Serendipity');

@define('SETTINGS_SAVED_AT', 'As novas configuraes foram guardadas em %s');
@define('PLUGIN_ITEM_DISPLAY', 'Aonde  que o item deve ser mostrado?');
@define('PLUGIN_ITEM_DISPLAY_EXTENDED', 'Apenas artigo extendido');
@define('PLUGIN_ITEM_DISPLAY_OVERVIEW', 'Pgina de viso geral apenas');
@define('PLUGIN_ITEM_DISPLAY_BOTH', 'Todas as vezes');
@define('RSS_IMPORT_CATEGORY', 'Utilize essa categoria para artigos que no encontrem uma categoria no Serendipity');
@define('ERROR_UNKNOWN_NOUPLOAD', 'Ocorreu um erro desconhecido, o arquivo no foi transferido. Talvez o tamanho do arquivo seja maior que o permitido pelo seu servidor. Verifique com o seu servidor de internet, ou edite o php.ini para permitir transferncia de arquivos de maior tamanho.');
@define('COMMENTS_WILL_BE_MODERATED', 'Comentrios enviados estaro sujeitos a moderao antes de serem exibidos.');
@define('YOU_HAVE_THESE_OPTIONS', 'As seguintes opes esto disponveis');
@define('THIS_COMMENT_NEEDS_REVIEW', 'Ateno: Esse comentrio precisa de aprovao antes de ser exibido');
@define('DELETE_COMMENT', 'Excluir comentrio');
@define('APPROVE_COMMENT', 'Aprovar comentrio');
@define('REQUIRES_REVIEW', 'Requer reviso');
@define('COMMENT_APPROVED', 'Comentrio #%s foi aprovado corretamente');
@define('COMMENT_DELETED', 'Comentrio #%s foi excludo corretamente');
@define('VIEW', 'Exibir');
@define('COMMENT_ALREADY_APPROVED', 'Comentrio #%s parece j ter sido aprovado');
@define('COMMENT_EDITED', 'O comentrio selecionado foi editado');
@define('HIDE', 'Ocultar');
@define('VIEW_EXTENDED_ENTRY', 'Continuar lendo "%s"');
@define('TRACKBACK_SPECIFIC_ON_CLICK', 'Este link no deve ser clicado. Contm a URL de trackback para este artigo. Use esse URL para enviar ping - & trackbacks do seu weblog para este artigo. Para copiar o link, clique com o boto direito e selecione "Copiar Atalho" no Internet Explorer ou "Copiar localizao do link" no Mozilla.');
@define('THIS_TRACKBACK_NEEDS_REVIEW', 'Ateno: Esse trackback precisa de aprovao antes que seja exibido');
@define('DELETE_TRACKBACK', 'Excluir trackback');
@define('APPROVE_TRACKBACK', 'Aprovar trackback');
@define('TRACKBACK_APPROVED', 'O trackback #%s foi aprovado corretamente');
@define('TRACKBACK_DELETED', 'O trackback #%s foi excludo corretamente');
@define('COMMENTS_MODERATE', 'Comentrios & trackbacks para este artigo requerem moderao');
@define('PLUGIN_SUPERUSER_HTTPS', 'Usar https para login');
@define('PLUGIN_SUPERUSER_HTTPS_DESC', 'Permitir que o link de login aponte para uma link https. O seu servidor web necessita de suportar esta opo!');
@define('INSTALL_SHOW_EXTERNAL_LINKS', 'Tornar clicveis os links externos?');
@define('INSTALL_SHOW_EXTERNAL_LINKS_DESC', '"no": Links externos no marcados (Maiores sadas, Maiores referncias, Comentrios de usurios) no so exibidos como puro texto para evitar spam do Google (recomendado). "sim": Links externos no marcados so exibidos como links. Podem ser sobrescritos pela configurao da barra lateral!');
@define('PAGE_BROWSE_COMMENTS', 'Pgina %s de %s, totalizando %s comentrios');
@define('FILTERS', 'Filtros');
@define('FIND_ENTRIES', 'Encontrar artigos');
@define('FIND_COMMENTS', 'Encontrar comentrios');
@define('FIND_MEDIA', 'Encontrar multimdia');
@define('FILTER_DIRECTORY', 'Directoria');
@define('SORT_BY', 'Ordenar por');
@define('TRACKBACK_COULD_NOT_CONNECT', 'Nenhum trackback enviado: No foi possvel abrir conexo para %s na porta %d');
@define('MEDIA', 'Multimdia');
@define('MEDIA_LIBRARY', 'Biblioteca de multimdia');
@define('ADD_MEDIA', 'Adicionar multimdia');
@define('ENTER_MEDIA_URL', 'Introduza a URL de um ficheiro para ir busc-lo:');
@define('ENTER_MEDIA_UPLOAD', 'Seleccione o ficheiro que deseja transferir:');
@define('SAVE_FILE_AS', 'Guardar ficheiro como:');
@define('STORE_IN_DIRECTORY', 'Guardar na seguinte directoria: ');
@define('MEDIA_RENAME', 'Renomear este ficheiro');
@define('IMAGE_RESIZE', 'Redimensionar esta imagem');
@define('MEDIA_DELETE', 'Apagar este ficheiro');
@define('FILES_PER_PAGE', 'Ficheiros por pgina');
@define('CLICK_FILE_TO_INSERT', 'Clique no ficheiro que deseja inserir:');
@define('SELECT_FILE', 'Seleccione arquivo para inserir');
@define('MEDIA_FULLSIZE', 'Tamanho total');
@define('CALENDAR_BOW_DESC', 'Dia da semana que deve ser considerado o incio da semana. O padro  segunda-feira');
@define('SUPERUSER', 'Administrao do weblog');
@define('ALLOWS_YOU_BLAHBLAH', 'Fornece um link para a administrao do weblog na barra lateral ');
@define('CALENDAR', 'Calendrio');
@define('SUPERUSER_OPEN_ADMIN', 'Abrir Administrao');
@define('SUPERUSER_OPEN_LOGIN', 'Abrir painel de login');
@define('INVERT_SELECTIONS', 'Inverter Seleo');
@define('COMMENTS_DELETE_CONFIRM', 'Tem a certeza de que deseja excluir os comentrios selecionados?');
@define('COMMENT_DELETE_CONFIRM', 'Tem a certeza de que deseja excluir o comentrio #%d, escrito por %s?');
@define('DELETE_SELECTED_COMMENTS', 'Excluir comentrios seleccionados');
@define('VIEW_COMMENT', 'Exibir comentrio');
@define('VIEW_ENTRY', 'Exibir artigo');
@define('DELETE_FILE', 'Excluir o campo entitulado <b>%s</b>');
@define('ABOUT_TO_DELETE_FILE', 'Voc est prestes a apagar <b>%s</b><br />Se estiver utilizando esse arquivo em algum dos seus artigos, vai resultar em ligaes ou imagens perdidas<br />Deseja realmente prosseguir com a excluso?<br /><br />');
@define('TRACKBACK_SENDING', 'Enviando trackback para o URL %s...');
@define('TRACKBACK_SENT', 'Trackback enviada com sucesso');
@define('TRACKBACK_FAILED', 'Trackback falhou: %s');
@define('TRACKBACK_NOT_FOUND', 'Nenhum URI de trackback foi encontrado.');
@define('TRACKBACK_URI_MISMATCH', 'A URI de trackback descoberta no com  semelhante ao URL alvo.');
@define('TRACKBACK_CHECKING', 'Verificando <u>%s</u> para possveis trackbacks...');
@define('TRACKBACK_NO_DATA', 'O alvo no contm dados');
@define('TRACKBACK_SIZE', 'URL alvo excedeu o tamanho mximo de %s bytes para um arquivo.');
@define('VIEWMODE_THREADED', 'Alternar para exibio por discusso');
@define('COMMENTS_VIEWMODE_THREADED', 'Discusso');
@define('COMMENTS_VIEWMODE_LINEAR', 'Sequencial');
@define('DISPLAY_COMMENTS_AS', 'Exibir comentrios como');
@define('DATE_FORMAT_SHORT', '%d/%m/%Y %H:%M');
@define('NUMBER_FORMAT_DECIMALS', '2');
@define('NUMBER_FORMAT_DECPOINT', ',');
@define('NUMBER_FORMAT_THOUSANDS', '.');
@define('CATEGORY_DELETED_ARTICLES_MOVED', 'Categoria #%s excluda. Os artigos antigos foram movidos para a categoria #%s');
@define('INSTALL_TOP_AS_LINKS', 'Exibir maiores sadas/referncias como links?');
@define('INSTALL_TOP_AS_LINKS_DESC', '"no": Sadas e Referncias so exibidas como puro texto para prevenir spam do google. "sim": Sadas e Refrncias so exibidas como links. "padro": Usa o valor definido na configurao global (recomendado).');
@define('ADD_MEDIA_BLAHBLAH', '<b>Adicionar um ficheiro para o seu repositrio de multimdia:</b><p>Aqui voc pode transferir ficheiros de multimdia, ou oriente-me para obt-lo noutro stio da web! Se no possuir uma imagem apropriada, <a href="http://images.google.com" target="_blank">procure no google</a> alguma imagem que tenha relao com o assunto, os resultados so geralmente teis e divertidos :)</p><p><b>Selecione o mtodo:</b></p><br/>');
@define('COMMENTS_FILTER_SHOW', 'Mostrar');
@define('COMMENTS_FILTER_ALL', 'Todos');
@define('COMMENTS_FILTER_APPROVED_ONLY', 'S aprovados'); // Verify
@define('COMMENTS_FILTER_NEED_APPROVAL', 'Aprovao pendente');
@define('RSS_IMPORT_BODYONLY', 'Pr todo o texto importado na seco de "body" ("corpo") e no dividir para a seco "extended entry" ("entrada estendida").'); // Verify
@define('SYNDICATION_PLUGIN_FULLFEED', 'Mostrar artigos completos com corpo estendido dentro do RSS feed');
@define('MT_DATA_FILE', 'Ficheiro de dados Movable Type');
@define('FORCE', 'Forar');
@define('CREATE_AUTHOR', 'Criar autor \'%s\'.');
@define('CREATE_CATEGORY', 'Criar categoria \'%s\'.');
@define('MYSQL_REQUIRED', 'Tem que ter a extenso MySQL para poder executar esta aco.');
@define('COULDNT_CONNECT', 'Foi impossvel ligar  base de dados MySQL: %s.');
@define('COULDNT_SELECT_DB', 'Foi impossvel seleccionar base de dados: %s.');
@define('COULDNT_SELECT_USER_INFO', 'Foi impossvel seleccionar a informao sobre o utilizador: %s.');
@define('COULDNT_SELECT_CATEGORY_INFO', 'No foi possvel seleccionar a informao de categorias: %s.');
@define('COULDNT_SELECT_ENTRY_INFO', 'No foi possvel seleccionar a informao da entrada: %s.');
@define('COULDNT_SELECT_COMMENT_INFO', 'No foi possvel seleccionar a informao de comentrios: %s.');
@define('WEEK', 'Semana');
@define('WEEKS', 'Semanas');
@define('MONTHS', 'Meses');
@define('DAYS', 'Dias');
@define('ARCHIVE_FREQUENCY', 'Frequncia de item de calendrio');
@define('ARCHIVE_FREQUENCY_DESC', 'O intervalo de calendrio entre cada item da lista');
@define('ARCHIVE_COUNT', 'Nmero de itens nesta lista');
@define('ARCHIVE_COUNT_DESC', 'O nmero total de meses, semanas ou dias para mostrar');
@define('BELOW_IS_A_LIST_OF_INSTALLED_PLUGINS', 'Abaixo encontra uma lista dos plugins instalados');
@define('SIDEBAR_PLUGIN', 'plugin da barra lateral');
@define('EVENT_PLUGIN', 'plugin de evento');
@define('CLICK_HERE_TO_INSTALL_PLUGIN', 'Clique aqui para instalar um novo %s');
@define('VERSION', 'verso');
@define('INSTALL', 'Instalar');
@define('ALREADY_INSTALLED', 'J instalado');
@define('SELECT_A_PLUGIN_TO_ADD', 'Seleccione o plugin que pretende instalar');
@define('INSTALL_OFFSET', 'Offset temporal no servidor');
@define('STICKY_POSTINGS', 'Postagens fixas'); // Translate ?
@define('INSTALL_FETCHLIMIT', 'Entradas a mostrar na primeira pgina');
@define('INSTALL_FETCHLIMIT_DESC', 'Nmero de entradas a mostrar por cada pgina do pgina principal'); // Translate frontend?
@define('IMPORT_ENTRIES', 'Importar dados');
@define('EXPORT_ENTRIES', 'Exportar entradas');
@define('IMPORT_WELCOME', 'Bem vindo ao utilitrio de importao do Serendipity');
@define('IMPORT_WHAT_CAN', 'Aqui podemos importar entradas de outro software gestor de weblogs');
@define('IMPORT_SELECT', 'Por favor, seleccione o software de onde quer importar');
@define('IMPORT_PLEASE_ENTER', 'Por favor introduza os dados como pedido abaixo');
@define('IMPORT_NOW', 'Importar agora!');
@define('IMPORT_STARTING', 'Comeando o procedimento de importao...');
@define('IMPORT_FAILED', 'Importao falhou');
@define('IMPORT_DONE', 'Importao completada com sucesso');
@define('IMPORT_WEBLOG_APP', 'Aplicao do Weblog');
@define('EXPORT_FEED', 'Exportar RSS feed completo'); // Verify
@define('STATUS', 'Status depois da importao');
@define('IMPORT_GENERIC_RSS', 'Importao de RSS genrica');
@define('ACTIVATE_AUTODISCOVERY', 'Enviar Trackbacks de ligaes encontradas na entrada'); // Verify
@define('WELCOME_TO_ADMIN', 'Bem vindo  Suite Administrativa do Serendipity.');
@define('PLEASE_ENTER_CREDENTIALS', 'Por favor, introduza as suas credenciais abaixo.');
@define('ADMIN_FOOTER_POWERED_BY', 'Equipado com Serendipity %s e PHP %s');
@define('INSTALL_USEGZIP', 'Use pginas comprimidas com gzip');
@define('INSTALL_USEGZIP_DESC', 'Para acelerar o acesso s pginas, podemos comprimi-las, desde que o navegador do visitante o suporte. Isto  recomendado');
@define('INSTALL_SHOWFUTURE', 'Mostre entradas futuras'); // Verify
@define('INSTALL_SHOWFUTURE_DESC', 'Se escolhido, isto mostrar todas as entradas futuras do seu blogue. Por omisso escondemos tais entradas e s so mostradas quando a data de publicao chega.');
@define('INSTALL_DBPERSISTENT', 'Usar conexes persistentes');
@define('INSTALL_DBPERSISTENT_DESC', 'Permitir a utilizao de conexes permanentes  base de dados, ver leitura adicional em <a href="http://php.net/manual/features.persistent-connections.php" target="_blank">aqui</a>. Isto normalmente no  recomendado.');
@define('NO_IMAGES_FOUND', 'Nenhuma das imagens foi encontrada');
@define('PERSONAL_SETTINGS', 'Preferncias pessoais');
@define('REFERER', 'Referenciador');
@define('NOT_FOUND', 'No encontrado');
@define('NOT_WRITABLE', 'Escrita negada');
@define('WRITABLE', 'Escrita permitida');
@define('PROBLEM_DIAGNOSTIC', 'Devido a um diagnstico problemtico, no se pode continuar a instalao sem que os erros acima sejam corrigidos');
@define('SELECT_INSTALLATION_TYPE', 'Seleccione que tipo de instalao que deseja efectuar');
@define('WELCOME_TO_INSTALLATION', 'Bem vindo  Instalao do Serendipity');
@define('FIRST_WE_TAKE_A_LOOK', 'Primeiro examinamos a sua instalao corrente e tentamos diagnosticar quaisquer problemas de compatibilidade');
@define('ERRORS_ARE_DISPLAYED_IN', 'Erros so mostrados a %s, recomendaes a %s e sucesso a %s');
@define('RED', 'vermelho');
@define('YELLOW', 'amarelo');
@define('GREEN', 'verde');
@define('PRE_INSTALLATION_REPORT', 'Relatrio de pr-instalao do Serendipity v%s');
@define('RECOMMENDED', 'Recomendado');
@define('ACTUAL', 'Actual'); // Verify
@define('PHPINI_CONFIGURATION', 'configurao em php.ini');
@define('PHP_INSTALLATION', 'instalao de PHP installation');
@define('THEY_DO', 'eles fazem'); // Translate
@define('THEY_DONT', 'eles no'); // Translate
@define('SIMPLE_INSTALLATION', 'Instalao simples');
@define('EXPERT_INSTALLATION', 'Instalao para especialistas');
@define('COMPLETE_INSTALLATION', 'Instalao completa');
@define('WONT_INSTALL_DB_AGAIN', 'no instalaremos a base de dados novamente'); // Verify
@define('CHECK_DATABASE_EXISTS', 'Verificando se a base de dados ou se as tabelas j existem');
@define('CREATING_PRIMARY_AUTHOR', 'Criando autor primrio \'%s\'');
@define('SETTING_DEFAULT_TEMPLATE', 'Definindo modelo por omisso'); // Verify
@define('INSTALLING_DEFAULT_PLUGINS', 'Instalando plugins por omisso'); // Verify
@define('SERENDIPITY_INSTALLED', 'Serendipity foi instalado com sucesso');
@define('VISIT_BLOG_HERE', 'Visite o seu novo blogue aqui');
@define('THANK_YOU_FOR_CHOOSING', 'Obrigado por escolher Serendipity');
@define('ERROR_DETECTED_IN_INSTALL', 'Erro detectado na instalao');
@define('OPERATING_SYSTEM', 'Sistema Operativo');
@define('WEBSERVER_SAPI', 'Servidor web SAPI');
@define('IMAGE_ROTATE_LEFT', 'Rodar a imagem 90 no sentido directo');
@define('IMAGE_ROTATE_RIGHT', 'Rodar a imagem 90 no sentido retrgado');
@define('TEMPLATE_SET', '\'%s\' foi definido como o seu modelo activo');
@define('SEARCH_ERROR', 'A funo de busca no se comportou como esperado. Nota para o Administrador deste blogue: isto pode acontecer por falta de chaves no ndice na sua base de dados. Em sistemas de MySQL, a sua conta de utilizador da base de dados precisa de privilgios para executar o seguinte comando: <pre>CREATE FULLTEXT INDEX entry_idx on %sentries (title,body,extended)</pre> O erro exacto reportado pela base de dados foi: <pre>%s</pre>'); // Verify
@define('EDIT_THIS_CAT', 'Editar "%s"');
@define('CATEGORY_REMAINING', 'Apague esta categoria e mova as entradas para esta outra');
@define('CATEGORY_INDEX', 'Abaixo encontra uma listagem de categorias disponveis para as suas entradas');
@define('NO_CATEGORIES', 'Sem categorias'); // Verify
@define('RESET_DATE', 'Reinicializar a data');
@define('RESET_DATE_DESC', 'Clique aqui para reinicializar a data para o valor corrente');
@define('PROBLEM_PERMISSIONS_HOWTO', 'Permisses podem ser corrigidas na directoria problemtica com o comando: `<em>%s</em>`, ou usando um programa de FTP'); // Verify
@define('WARNING_TEMPLATE_DEPRECATED', 'Aviso: o seu modelo corrente usa um mtodo de padres obsoleto, fica avisado para actualizar se possvel');
@define('ENTRY_PUBLISHED_FUTURE', 'Esta entrada ainda no foi publicada.');
@define('ENTRIES_BY', 'Entradas por %s');
@define('PREVIOUS', 'Anterior');
@define('NEXT', 'Seguinte');
@define('APPROVE', 'Aprovar');
@define('DO_MARKUP_DESCRIPTION', 'Aplicar transformaes nos cdigos do texto (smilies, abreviaturas via *, /, _, ...). Desligando esta funo ir preservar qualquer cdigo HTML no texto.');
@define('CATEGORY_ALREADY_EXIST', 'Uma categoria com o nome "%s" j existe');
@define('IMPORT_NOTES', 'Nota:');
@define('ERROR_FILE_FORBIDDEN', 'No  permitido fazer upload de ficheiros com contedo activo'); // Verify
@define('ADMIN', 'Administrao');
@define('ADMIN_FRONTPAGE', 'Primeira pgina');
@define('QUOTE', 'Citar'); // Verify
@define('IFRAME_SAVE', 'Serendipity est guardando a sua entrada, criando trackbacks e realizando possveis chamadas de XML-RPC. Isto pode demorar um pouco...');
@define('IFRAME_SAVE_DRAFT', 'Um rascunho desta entrada foi guardado');
@define('IFRAME_PREVIEW', 'Serendipity est agora a criar uma previso da sua entrada...');
@define('IFRAME_WARNING', 'O seu navegador no suporta o conceito de iframes. Por favor abra o seu ficheiro serendipity_config.inc.php e defina a varivel $serendipity[\'use_iframe\'] como FALSE.'); // Verify
@define('NONE', 'nenhum');
@define('USERCONF_CAT_DEFAULT_NEW_ENTRY', 'Caractersticas por omisso de novas entradas');
@define('UPGRADE', 'Actualizar');
@define('UPGRADE_TO_VERSION', 'Actualizar para a verso %s');
@define('DELETE_DIRECTORY', 'Apagar directoria');
@define('DELETE_DIRECTORY_DESC', 'Est prestes a apagar o contedo duma directoria que contm ficheiros de multimdia que podem ser usados por outras das suas entradas.'); // Verify
@define('FORCE_DELETE', 'Apagar TODOS os ficheiros nesta directoria, incluindo os desconhecidos pelo Serendipity');
@define('CREATE_DIRECTORY', 'Criar directoria');
@define('CREATE_NEW_DIRECTORY', 'Criar nova directoria');
@define('CREATE_DIRECTORY_DESC', 'Aqui pode criar uma nova directoria aonde colocar ficheiros multimdia. Escolha o nome para a nova directoria e seleccione se necessrio a directoria onde aquela  colocada.'); // Verify
@define('BASE_DIRECTORY', 'Directoria base');
@define('USERLEVEL_EDITOR_DESC', 'Editor');
@define('USERLEVEL_CHIEF_DESC', 'Editor Chefe');
@define('USERLEVEL_ADMIN_DESC', 'Administrador');
@define('USERCONF_USERLEVEL', 'Nvel de acesso');
@define('USERCONF_USERLEVEL_DESC', 'Este nvel  usado para determinar que tipo de acesso ao blogue tem este utilizador');
@define('USER_SELF_INFO', 'Conectado como %s (%s)'); // Verify
@define('ADMIN_ENTRIES', 'Entradas');
@define('RECHECK_INSTALLATION', 'Volte a verificar a instalao');
@define('IMAGICK_EXEC_ERROR', 'Impossvel executar: "%s", erro: %s, varivel devolvida: %d');
@define('INSTALL_OFFSET_DESC', 'Introduza a diferena horria entre o seu servicor (corrente: %clock%) e o fuso horrio pretendido');
@define('UNMET_REQUIREMENTS', 'Requisitos falharam: %s');
@define('CHARSET', 'Codificao de caracteres');
@define('AUTOLANG', 'Por omisso usar a linguagem do navegador do visitante');
@define('AUTOLANG_DESC', 'Se escolhido, isto usar a linguagem do navegador do utilizador para determinar a linguagem por omisso da sua entrada e a linguagem da interface.');
@define('INSTALL_AUTODETECT_URL', 'Autodetectar HTTP-Host utilizado');
@define('INSTALL_AUTODETECT_URL_DESC', 'Se definido como "true", o Serendipity assegurar que o HTTP Host que  usado pelo seu visitante  usado como definio de BaseURL. Permitir isto torna possvel usar vrios nomes de domnio para o seu blogue Serendipity, e usar o domnio para todas as ligaes subsequentes.'); // Verify
@define('CONVERT_HTMLENTITIES', 'Tentar converter as entidades HTML?');
@define('EMPTY_SETTING', 'No especificou um valor vlido para "%s"!');
@define('USERCONF_REALNAME', 'Nome verdadeiro');
@define('USERCONF_REALNAME_DESC', 'O nome completo do autor. Este  o nome visto pelos leitores');
@define('HOTLINK_DONE', 'Ficheiro hotlinked.<br />Feito.'); // Verify
@define('ENTER_MEDIA_URL_METHOD', 'Mtodo de obteno:');
@define('ADD_MEDIA_BLAHBLAH_NOTE', 'Nota: Se escolher fazer um hotlink para  o servidor, assegure-se que tem permisso para tal ou que o servidor  seu. Hotlinks permitem usar imagens sem as guardar localmente.'); // Verify
@define('MEDIA_HOTLINKED', 'hotlinked'); // Translate?
@define('FETCH_METHOD_IMAGE', 'Download da imagem para o seu servidor');
@define('FETCH_METHOD_HOTLINK', 'Hotlink para servidor'); // Verify
@define('DELETE_HOTLINK_FILE', 'Apagado o ficheiro hotlinked intitulado <b>%s</b>'); // Verify
@define('SYNDICATION_PLUGIN_SHOW_MAIL', 'Mostrar endereos de e-mail?');
@define('IMAGE_MORE_INPUT', 'Adicionar imagens');
@define('BACKEND_TITLE', 'Informao adicional no cr de configurao de plugins');
@define('BACKEND_TITLE_FOR_NUGGET', 'Aqui pode definir um pedao de texto personalizado que  mostrado no cr de configurao de plugins juntamente com a descrio do plugin HTML Nugget. Se tiver mltiplos HTML nuggets com um ttulo por preencher, isto permite distinguir os plugins entre si.');
@define('CATEGORIES_ALLOW_SELECT', 'Permitir aos visitantes mostrar mltiplas categorias simultaneamente?');
@define('CATEGORIES_ALLOW_SELECT_DESC', 'Se esta opo for activada, uma caixa de marcao ser posta ao lado de cada categoria no plugin da barra lateral. Os utilizadores podem marcar estas caixas e depois ver as entradas correspondendo  sua seleco.'); // Verify
@define('PAGE_BROWSE_PLUGINS', 'Pgina %s de %s, totalizando %s plugins.');
@define('INSTALL_CAT_PERMALINKS', 'Links Pernamentes'); // Translate ?
@define('INSTALL_CAT_PERMALINKS_DESC', 'Define vrios padres de URLs para definir ligaes permanentes no seu blogue.  sugerido que use as escolhas por omisso; caso contrrio, dever tentar usar o valor da %id% sempre que possvel para evitar que o Serendipity pergunte  base de dados pela URL alvo.'); // Verify
@define('INSTALL_PERMALINK', 'Estrutura de introduo do URL de Links Pernamentes'); // Verify
@define('INSTALL_PERMALINK_DESC', 'Aqui pode definir a estrura relativa de URLs do seu URL base at onde as entradas esto disponveis. Pode usar as variveis %id%, %title%, %day%, %month%, %year% e quaisquer outros caracteres..'); // Verify
@define('INSTALL_PERMALINK_AUTHOR', 'Estrutura de URL de Links Pernamentes do Autor'); // Verify
@define('INSTALL_PERMALINK_AUTHOR_DESC', 'Aqui pode definir a estrura relativa dos URLs do seu URL base at onde entradas para certos autores ficam disponveis. Pode usar as variveis %id%, %realname%, %username%, %email% e quaisquer outros caracteres.'); // Verify
@define('INSTALL_PERMALINK_CATEGORY', 'Estrutura do URL para Links Pernamentes por Categoria'); // Verify
@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Aqui pode definir a estrura relativa dos URLs do seu URL base at onde entradas para certas categorias ficam disponveis. Pode usar as variveis %id%, %name%, %description% e quaisquer outros caracteres.'); // Verify
@define('INSTALL_PERMALINK_FEEDCATEGORY', 'Estrutura do URL para Links Permanentes por Categoria de RSS-Feed'); // Verify
@define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'Aqui pode definir a estrutura relativa dos URLs d seu URL base at onde entradas para certas categorias de RSS-Feed ficam disponveis. Pode usar as variveis %id%, %name%, %description% e quaisquer outros caracteres.'); // Verify
@define('INSTALL_PERMALINK_ARCHIVESPATH', 'Caminho para arquivos');
@define('INSTALL_PERMALINK_ARCHIVEPATH', 'Caminho para arquivo');
@define('INSTALL_PERMALINK_CATEGORIESPATH', 'Caminho para categorias');
@define('INSTALL_PERMALINK_UNSUBSCRIBEPATH', 'Caminho para desistir da subscrio de comentrios');
@define('INSTALL_PERMALINK_DELETEPATH', 'Caminho para apagar comentrios');
@define('INSTALL_PERMALINK_APPROVEPATH', 'Caminho para aprovar comentrios');
@define('INSTALL_PERMALINK_FEEDSPATH', 'Caminho para RSS Feeds');
@define('INSTALL_PERMALINK_PLUGINPATH', 'Caminho para plugin nico'); //Verify
@define('INSTALL_PERMALINK_ADMINPATH', 'Caminho para Administrao');
@define('INSTALL_PERMALINK_SEARCHPATH', 'Caminho para a pesquisa'); //Verify
@define('INSTALL_CAL', 'Gnero de calendrio');
@define('INSTALL_CAL_DESC', 'Escolha o formato de calendrio desejado');
@define('REPLY', 'Responder');
@define('USERCONF_GROUPS', 'Inscries em grupos');
@define('USERCONF_GROUPS_DESC', 'Este utilizador  membro dos seguintes grupos. Inscries mltiplas so possveis.');
@define('MANAGE_GROUPS', 'Gesto de grupos');
@define('DELETED_GROUP', 'O grupo #%d %s foi apagado.');
@define('CREATED_GROUP', 'Um novo grupo %s foi criado');
@define('MODIFIED_GROUP', 'As propriedades do grupo %s foram mudadas');
@define('GROUP', 'Grupo');
@define('CREATE_NEW_GROUP', 'Criar novo grupo');
@define('DELETE_GROUP', 'Est prestes a apagar o grupo #%d %s. Tem a certeza?');
@define('USERLEVEL_OBSOLETE', 'AVISO: O atributo de nvel de utilizador  agora s usado para compatibilidade com plugins ou como mtodo de autorizao substituto. Privilgios de utilizador so geridos por inscrio em grupos!'); //Verify
@define('SYNDICATION_PLUGIN_FEEDBURNERID', 'ID do FeedBurner');
@define('SYNDICATION_PLUGIN_FEEDBURNERID_DESC', 'O ID do feed que deseja publicar');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG', 'Imagem do FeedBurner');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG_DESC', 'Nome da imagem a mostrar (ou deixe em branco para contador), localizada em feedburner.com, ex: fbapix.gif');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE', 'Ttulo do FeedBurner');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE_DESC', 'Ttulo (se pretendido) a mostrar ao lado da imagem');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT', 'Texto da imagem do FeedBurner');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT_DESC', 'Texto (se pretendido) a mostrar quando se pairao cursor sobre a imagem');
@define('SEARCH_TOO_SHORT', 'O texto a procurar dever ter mais que 3 caracteres. Pode usar * como sufixo, por exemplo s9y*, para forar a pesquisa por palavras mais pequenas.');
@define('INSTALL_DBPORT', 'Porto da base de dados'); //Verify
@define('INSTALL_DBPORT_DESC', 'Porto usado para ligar ao servidor da base de dados');
@define('PLUGIN_GROUP_FRONTEND_EXTERNAL_SERVICES', 'Frontend: Servios Externos');
@define('PLUGIN_GROUP_FRONTEND_FEATURES', 'Frontend: Caractersticas');
@define('PLUGIN_GROUP_FRONTEND_FULL_MODS', 'Frontend: Modificaes ');
@define('PLUGIN_GROUP_FRONTEND_VIEWS', 'Frontend: Vistas');
@define('PLUGIN_GROUP_FRONTEND_ENTRY_RELATED', 'Frontend: Relacionado com Entradas');
@define('PLUGIN_GROUP_BACKEND_EDITOR', 'Backend: Editor');
@define('PLUGIN_GROUP_BACKEND_USERMANAGEMENT', 'Backend: Gesto de Utilizadores');
@define('PLUGIN_GROUP_BACKEND_METAINFORMATION', 'Backend: Meta informao');
@define('PLUGIN_GROUP_BACKEND_TEMPLATES', 'Backend: Modelos');
@define('PLUGIN_GROUP_BACKEND_FEATURES', 'Backend: Caractersticas');
@define('PLUGIN_GROUP_IMAGES', 'Imagens');
@define('PLUGIN_GROUP_ANTISPAM', 'Anti-Spam');
@define('PLUGIN_GROUP_MARKUP', 'Cdigo');
@define('PLUGIN_GROUP_STATISTICS', 'Estatsticas');
@define('PERMISSION_PERSONALCONFIGURATION', 'personalConfiguration: Aceder  configurao pessoal');
@define('PERMISSION_PERSONALCONFIGURATIONUSERLEVEL', 'personalConfigurationUserlevel: Modificar nveis de utilizador');
@define('PERMISSION_PERSONALCONFIGURATIONNOCREATE', 'personalConfigurationNoCreate: Mudar "proibir criao de entradas"');
@define('PERMISSION_PERSONALCONFIGURATIONRIGHTPUBLISH', 'personalConfigurationRightPublish: Mudar direito de publicar entradas');
@define('PERMISSION_SITECONFIGURATION', 'siteConfiguration: Aceder  configurao de sistema');
@define('PERMISSION_BLOGCONFIGURATION', 'blogConfiguration: Aceder  configurao blogo-cntrica');
@define('PERMISSION_ADMINENTRIES', 'adminEntries: Administrar entradas');
@define('PERMISSION_ADMINENTRIESMAINTAINOTHERS', 'adminEntriesMaintainOthers: Administrar entradas de outros utilizadores');
@define('PERMISSION_ADMINIMPORT', 'adminImport: Importar entradas');
@define('PERMISSION_ADMINCATEGORIES', 'adminCategories: Administrar categorias');
@define('PERMISSION_ADMINCATEGORIESMAINTAINOTHERS', 'adminCategoriesMaintainOthers: Administrar outras categorias dos utilizadores');
@define('PERMISSION_ADMINCATEGORIESDELETE', 'adminCategoriesDelete: Apagar categorias');
@define('PERMISSION_ADMINUSERS', 'adminUsers: Administrar utilizadores');
@define('PERMISSION_ADMINUSERSDELETE', 'adminUsersDelete: Apagar utilizadores');
@define('PERMISSION_ADMINUSERSEDITUSERLEVEL', 'adminUsersEditUserlevel: Mudar nvel de utilizador');
@define('PERMISSION_ADMINUSERSMAINTAINSAME', 'adminUsersMaintainSame: Administrar utilizadores do(s) seu(s) grupo(s)');
@define('PERMISSION_ADMINUSERSMAINTAINOTHERS', 'adminUsersMaintainOthers: Administrar utilizadores que no pertencem ao(s) seu(s) grupo(s)');
@define('PERMISSION_ADMINUSERSCREATENEW', 'adminUsersCreateNew: Criar novos utilizadores');
@define('PERMISSION_ADMINUSERSGROUPS', 'adminUsersGroups: Administrar grupos de utilizadores');
@define('PERMISSION_ADMINPLUGINS', 'adminPlugins: Administrar plugins');
@define('PERMISSION_ADMINPLUGINSMAINTAINOTHERS', 'adminPluginsMaintainOthers: Administrar plugins de outros utilizadores');
@define('PERMISSION_ADMINIMAGES', 'adminImages: Administrar ficheiros de multimdia');
@define('PERMISSION_ADMINIMAGESDIRECTORIES', 'adminImagesDirectories: Administrate directorias de multimdia');
@define('PERMISSION_ADMINIMAGESADD', 'adminImagesAdd: Juntar novos ficheiros de multimdia');
@define('PERMISSION_ADMINIMAGESDELETE', 'adminImagesDelete: Apagar ficheiros de multimdia');
@define('PERMISSION_ADMINIMAGESMAINTAINOTHERS', 'adminImagesMaintainOthers: Administrar ficheiros de multimdia de outros utilizadores');
@define('PERMISSION_ADMINIMAGESVIEW', 'adminImagesView: Ver ficheiros de multimdia');
@define('PERMISSION_ADMINIMAGESSYNC', 'adminImagesSync: Sincronizar thumbnails');
@define('PERMISSION_ADMINCOMMENTS', 'adminComments: Administrar comentrios');
@define('PERMISSION_ADMINTEMPLATES', 'adminTemplates: Administrar modelos');
@define('INSTALL_BLOG_EMAIL', 'Endereo de E-mail do Blogue');
@define('INSTALL_BLOG_EMAIL_DESC', 'Isto configura o endereo de E-mail que  usado na linha de "From" de e-mail que segue para o exterior. Certifique-se que isto  um endereo de e-mail que  reconhecido pelo servidor de mail configurado no seu servidor - muitos servidores de mail rejeitam mensagens com um endereo de "From"" desconhecido.');
@define('CATEGORIES_PARENT_BASE', 'Mostre s categorias abaixo...');
@define('CATEGORIES_PARENT_BASE_DESC', 'Pode escolher uma categoria antecessora para que s as categorias descendentes sejam vistas.');
@define('CATEGORIES_HIDE_PARALLEL', 'Esconder categorias que no fazem parte da rvore de categorias');
@define('CATEGORIES_HIDE_PARALLEL_DESC', 'Se quiser esconder categorias que fazem parte de uma rvore de categorias distinta,  preciso autorizar isto. Esta caracterstica faz sentido especialmente se usada com um multi-blogue usando o plugin de "Propriedades/Modelos de categorias".');
@define('PERMISSION_ADMINIMAGESVIEWOTHERS', 'adminImagesViewOthers: Ver ficheiros de multimdia de outros utilizadores');
@define('CHARSET_NATIVE', 'Nativo');
@define('INSTALL_CHARSET', 'Escolha de codificao de caracteres');
@define('INSTALL_CHARSET_DESC', 'Aqui pode optar entre codificaes de caracteres UTF-8 ou nativas (ISO, EUC, ...). Algumas lnguas s tm tradues UTF-8 de forma que mudar a codificao para "Nativo" no produzir qualquer efeito. Sugere-se UTF-8 em instalaes novas. No altere esta definio se j criou entradas com caracteres especiais - isso pode causar corrupo de caracteres. Certifique-se que l mais sobre este assunto em http://www.s9y.org/index.php?node=46.');
@define('CALENDAR_ENABLE_EXTERNAL_EVENTS', 'Accionar conexo ao Plugin API');
@define('CALENDAR_EXTEVENT_DESC', 'Se accionado, os plugins podem conectar ao calendrio para mostrar os seus eventos destacados. S accione se instalou plugins que precisam disto, caso contrrio o nico efeito  diminuir a performance.');
@define('XMLRPC_NO_LONGER_BUNDLED', 'A Interface da API de XML-RPC para Serendipity j no  includa devido a questes de segurana correntes com esta API e ao facto de ser pouco usada. Assim precisa de instalar o Plugin de XML-RPC para usar a API de XML-RPC. A URL a usar nas suas aplicaes NO mudar - assim que instalar o plugin, poder de novo usar a API.');
@define('PERM_READ', 'Permisso de leitura');
@define('PERM_WRITE', 'Permisso de escrita');

@define('PERM_DENIED', 'Permisso negada.');
@define('INSTALL_ACL', 'Aplicar permisses de leitura s categorias');
@define('INSTALL_ACL_DESC', 'Se accionado, as preferncias de permisses de grupos de utilizadores que definir para categorias sero aplicadas quando utilizadores que fizeram login virem o seu blogue. Se inactivo, as permisses de leitura das categorias NO sero aplicadas, mas o efeito positivo  uma ligeira velocidade adicional no seu blogue. Assim se no precisar de permisses de leitura multi-utilizador para o seu blogue, inactive esta preferncia.');
@define('PLUGIN_API_VALIDATE_ERROR', 'Sintaxe de configurao errada para a opo "%s". Precisa de contedo do tipo "%s".');
@define('USERCONF_CHECK_PASSWORD', 'Senha antiga');
@define('USERCONF_CHECK_PASSWORD_DESC', 'Se mudar a senha no campo acima, precisa de inserir a senha corrente neste campo.');
@define('USERCONF_CHECK_PASSWORD_ERROR', 'No especificou a senha antiga correctamente, e no est autorizado a mudar a nova senha. As suas preferncias no foram guardadas.');
@define('ERROR_XSRF', 'O seu navegador no enviou uma sequncia vlida de HTTP-Referrer. Isto pode ter sido causado por um proxy ou navegador mal configurado ou por um Cross Site Request Forgery (XSRF) dirigido a si. A aco que solicitou no pde ser completada.');

@define('AUTHORS', 'Autores');
@define('AUTHORS_ALLOW_SELECT', 'Permitir aos visitantes ver mltiplos autores simultaneamente?');
@define('AUTHORS_ALLOW_SELECT_DESC', 'Se esta opo estiver escolhida, uma marca ser posta junto a cada autor no plugin de barra lateral. Os utilizadores podem alterar essas marcas para ver as entradas correspondentes  sua seleco.');
@define('AUTHOR_PLUGIN_DESC', 'Mostra uma lista de autores');
@define('CATEGORY_PLUGIN_TEMPLATE', 'Activar Smarty-Templates?');
@define('CATEGORY_PLUGIN_TEMPLATE_DESC', 'Se esta opo estiver activada, o plugin usar propriedades de Smarty-Templating para mostrar a lista de categorias. Se activar isto, pode mudar a formatao via o ficheiro modelo "plugin_categories.tpl". A activao desta opo ter um impacto na performance, de maneira que se no precisar de fazer adaptaes, deixe-a inactiva.');
@define('CATEGORY_PLUGIN_SHOWCOUNT', 'Mostrar nmero de entradas por categoria?');
@define('AUTHORS_SHOW_ARTICLE_COUNT', 'Mostrar nmero de artigos ao lado do nome nome do autor?');
@define('AUTHORS_SHOW_ARTICLE_COUNT_DESC', 'Se esta opo for activada, o nmero de artigos deste autor ser mostrado entre parntesis junto ao nome do Autor.');
@define('CUSTOM_ADMIN_INTERFACE', 'Interface Administrativa ad hoc disponvel');
@define('COMMENT_NOT_ADDED', 'Os seus comentrios no foram adicionados, porque ou comentrios para este artigo no esto autorizados, ou introduziu dados invlidos, ou os seus comentrios foram interceptados por medidas anti-spam. ');
@define('INSTALL_TRACKREF', 'Activar localizao do referenciador?');
@define('INSTALL_TRACKREF_DESC', 'A activao da localizao do referenciador permite mostrar que stios se referem aos seus artigos. Hoje em dia esta possibilidade  abusada para insero de spam, de maneira que pode deslig-la se quiser.');
@define('CATEGORIES_HIDE_PARENT', 'Esconder a categoria me seleccionada?');
@define('CATEGORIES_HIDE_PARENT_DESC', 'Se restringir a listagem de categorias a uma categoria especfica, por omisso ver a categoria me na listagem de sada. Se inactivar esta opo, o nome da categoria me no ser mostrado.');
@define('WARNING_NO_GROUPS_SELECTED', 'Aviso: No seleccionou afiliaes em grupos. Isto encerrou a sua gesto de grupos, e as suas afiliaes em grupos no foram alteradas.');
@define('INSTALL_RSSFETCHLIMIT', 'Entradas a mostrar nos Feeds');  // Verify
@define('INSTALL_RSSFETCHLIMIT_DESC', 'Nmero de entradas a mostrar por pgina do RSS Feed.'); // Verify
@define('INSTAL_DB_UTF8', 'Activar converso da codificao de caracteres na base de dados');
@define('INSTAL_DB_UTF8_DESC', 'Envia um comando MySQL "SET NAMES" para indicar a codificao de caracteres requerida para a base de dados. Ligue ou desligue, se vir caracteres estranhos no seu blogue.');
@define('ONTHEFLYSYNCH', 'Activar a sincronizao de multimdia instantnea');
@define('ONTHEFLYSYNCH_DESC', 'Se activado, o Serendipity comparar a base de dados de multimdia com os ficheiros guardados no seu servidor e sincronizar a base de dados com o contedo da directoria.');
@define('USERCONF_CHECK_USERNAME_ERROR', 'O nome do utilizador no pode ser deixado em branco.');
@define('FURTHER_LINKS', 'Ligaes adicionais');
@define('FURTHER_LINKS_S9Y', 'Stio do Serendipity');
@define('FURTHER_LINKS_S9Y_DOCS', 'Documentao do Serendipity');
@define('FURTHER_LINKS_S9Y_BLOG', 'Blogue Oficial');
@define('FURTHER_LINKS_S9Y_FORUMS', 'Fruns');
@define('FURTHER_LINKS_S9Y_SPARTACUS', 'Spartacus');
@define('COMMENT_IS_DELETED', '(Comentrio removido)');



// I translated in full this part of the language file, from english to portuguese, word by word,making use of Microsofts Word as addictional verification and PHP Designer 2007 Professional Editor as editor. --- $Angel (and I hopefully improved it, J P Matos; Obrigado $Angel).

@define('CURRENT_AUTHOR', 'Autor corrente');

@define('WORD_NEW', 'Novo');
@define('SHOW_MEDIA_TOOLBAR', 'Mostrar barra dentro do seleccionador de media-popup?');
@define('MEDIA_KEYWORDS', 'Palavras-chave para a Media');
@define('MEDIA_KEYWORDS_DESC', 'Entre uma listagem, de palavras separadas por ";" atravs das quais deseja pr-definir, via palavras-chave, os seus itens de media.');
@define('MEDIA_EXIF', 'Importar imagens EXIF/JPEG');
@define('MEDIA_EXIF_DESC', 'Uma vez activado, as imagens EXIF/JPEG existentes sero separadas e arquivadas na base de dados para exposio na galeria de media.');
@define('MEDIA_PROP', 'Propriedades da Media');


@define('GO_ADD_PROPERTIES', 'Ir & introduzir propriedades');
@define('MEDIA_PROPERTY_DPI', 'DPI (PPP)');
@define('MEDIA_PROPERTY_COPYRIGHT', 'Direitos de Autor');
@define('MEDIA_PROPERTY_COMMENT1', 'Comentrio Breve');
@define('MEDIA_PROPERTY_COMMENT2', 'Comentrio Longo');
@define('MEDIA_PROPERTY_TITLE', 'Ttulo');
@define('MEDIA_PROP_DESC', 'Entre uma listagem separada por ";" nos campos de propriedade, relativa ao modo como deseja definir cada um dos seus ficheiros Media');
@define('MEDIA_PROP_MULTIDESC', '(Voc pode colocar ":MULTI" aps algum item para indicar que o mesmo ir conter texto longo em vez de apenas alguns caracteres)');

@define('STYLE_OPTIONS_NONE', 'Este tema/estilo no tem opes especficas. Para visualizar como o seu modelo (template) pode expecificar opes, leia a Documentao Tcnica disponvel em www.s9y.org acerca de "Configuration of Theme options".');
@define('STYLE_OPTIONS', 'Opes de Tema/Estilo');

@define('PLUGIN_AVAILABLE_COUNT', 'Total: %d plugins.');

@define('SYNDICATION_RFC2616', 'Activar obedincia estrita ao RFC2616 RSS-Feed');
@define('SYNDICATION_RFC2616_DESC', 'NO forar o RFC2616 significa que todos os "Conditional GETs" pelo Serendipity iro devolver as ltimas entradas modificadas deste o seu ltimo pedido. Uma vez colocada a configurao como "false", os seus visitantes iro obter todos os artigos no seu ltimo pedido, o que  um bom resultado. No entanto, alguns Agentes tal como Planet iro agir de forma estranha, se tal acontecer, violando tambm o RFC2616. Se colocar esta opo como "TRUE", voc ir cumprir aquele RFC, mas os leitores do seu RSS Feed talvez percam alguns itens durante as frias. De qualquer forma, ou adora Agredadores como o Planet, ou fere os leitores actuais do seu Blogue. Se voc est a enfrentar queixas de ambos os lados, poder alterar esta opo. Referncia: <a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a>');
@define('MEDIA_PROPERTY_DATE', 'Data Associada');
@define('MEDIA_PROPERTY_RUN_LENGTH', 'Comprimento');
@define('FILENAME_REASSIGNED', 'Associa um novo ficheiro automaticamente: %s');
@define('MEDIA_UPLOAD_SIZE', 'Mximo do tamanho do ficheiro carregado');
@define('MEDIA_UPLOAD_SIZE_DESC', 'Introduza o tamanho mximo para upload de um ficheiro em bytes. Esta configurao poder ser reescrita pelas definies includas no servidor via o ficheiro php.ini: upload_max_filesize, post_max_size, max_input_time em todos os precedentes acima desta opo. Um string vazio significa que apenas sero usado os limites definidos no servidor.');
@define('MEDIA_UPLOAD_SIZEERROR', 'Erro: Voc no pode fazer upload de ficheiros maiores que %s bytes!');
@define('MEDIA_UPLOAD_MAXWIDTH', 'Mximo de largura de imagens no upload');
@define('MEDIA_UPLOAD_MAXWIDTH_DESC', 'Entre o mximo de largura permitido no upload em pixels.');
@define('MEDIA_UPLOAD_MAXHEIGHT', 'Mximo de altura de imagens no upload');
@define('MEDIA_UPLOAD_MAXHEIGHT_DESC', 'Entre o mximo de altura permitido por upload em pixels.');
@define('MEDIA_UPLOAD_DIMERROR', 'Erro: Voc no pode fazer upload de ficheiros maiores que %s x %s pixels!');

@define('MEDIA_TARGET', 'Alvo para esta ligao');
@define('MEDIA_TARGET_JS', 'Janela de Popup (via JavaScript, tamanho adaptvel)');
@define('MEDIA_ENTRY', 'Entrada isolada');
@define('MEDIA_TARGET_BLANK', 'Janela de Popup (via target=_blank)');

@define('MEDIA_DYN_RESIZE', 'Permitir redimencionamento dinmico de imagens?');
@define('MEDIA_DYN_RESIZE_DESC', 'Se activado, o seleccionador de media pode retornar as imagens em qualquer tamanho pretendido via a variante GET. Os resultados so colocados em cache, podendo criar um grande conjunto de ficheiros se fizer uso extensivo desta possibilidade.');

@define('MEDIA_DIRECTORY_MOVED', 'O Directrio tal como os ficheiros foram movidos com sucesso para %s');
@define('MEDIA_DIRECTORY_MOVE_ERROR', 'O Directrio tal como os ficheiros no puderam ser movidos para %s!');
@define('MEDIA_DIRECTORY_MOVE_ENTRY', 'Em bases de dados distintas de MySQL no  possvel intervir atravs de cada artigo para substituir o directrio antigo dos URLs com um novo directrio. Ser necessrio editar as suas entradas manualmente para corrigir novos URLs. Voc pode ainda repr o seu antigo directrio onde ele se encontrava, se isso for muito incmodo para si.');
@define('MEDIA_DIRECTORY_MOVE_ENTRIES', 'Moveu-se o URL do directrio alterado para estas %s entradas..');
@define('PLUGIN_ACTIVE', 'Activo');
@define('PLUGIN_INACTIVE', 'Inactivo');
@define('PREFERENCE_USE_JS', 'Activar utilizao de JavaScript Avanado?');
@define('PREFERENCE_USE_JS_DESC', 'Se activado, as seces com JavaScript avanado iro ser activadas para melhor utilizao, tal como a seco do plugin de configurao, "Plugin Configuration", poder ser usada por si para arrastar e colar plugins reorganizados.');

@define('PREFERENCE_USE_JS_WARNING', '(Esta pgina usa JavaScript avanado. Se est a deparar-se com problemas de funcionalidade, desactive por favor a utilizao de JavaScript avanado nas suas preferncias pessoais ou desactive a funo de JavaScript do seu Navegador.)');


@define('INSTALL_PERMALINK_COMMENTSPATH', 'Caminho para comentrios');
@define('PERM_SET_CHILD', 'Configure as mesmas permisses para todos os subdirectrios recursivamente');
@define('PERMISSION_FORBIDDEN_PLUGINS', 'Plugins proibidos');
@define('PERMISSION_FORBIDDEN_HOOKS', 'Eventos proibidos');
@define('PERMISSION_FORBIDDEN_ENABLE', 'Activar Plugin ACL para grupos?');
@define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'Se a opo "Plugin ACL para grupos" est activada na configurao, voc pode especificar que grupos esto autorizados a executar certos plugins/eventos.');
@define('DELETE_SELECTED_ENTRIES', 'Eliminar entradas seleccionadas');
@define('PLUGIN_AUTHORS_MINCOUNT', 'Mostar apenas Autores com um mnimo de X artigos');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Marque esta ligao e use-a em qualquer pgina em que quiser blogar para aceder rapidamente ao seu blogue Serendipity.');
@define('IMPORT_WP_PAGES', 'Ir tambm buscar ficheiros anexados e pginas estticas como entradas de blog normais?');
@define('USERCONF_CREATE', 'Disable user / forbid activity?');
@define('USERCONF_CREATE_DESC', 'If selected, the user will not have any editing or creation possibilities on the blog anymore. When logging in to the backend, he cannot do anything else apart from logging out and viewing his personal configuration.');
@define('CATEGORY_HIDE_SUB', 'Hide postings made to sub-categories?');
@define('CATEGORY_HIDE_SUB_DESC', 'By default, when you browse a category also entries of any subcategory are displayed. If this option is turned on, only postings of the currently selected category are displayed.');
@define('PINGBACK_SENDING', 'Sending pingback to URI %s...');
@define('PINGBACK_SENT', 'Pingback successful');
@define('PINGBACK_FAILED', 'Pingback failed: %s');
@define('PINGBACK_NOT_FOUND', 'No pingback-URI found.');
@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Hide archives link when no entries were made in that timespan (requires counting entries)');
@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
